@@ -3,10 +3,10 @@
  *
  * Ref: NIST FIPS PUB 180-4 Secure Hash Standard
  *
- * Copyright (C) 2003-2014 Mark Shelor, All Rights Reserved
+ * Copyright (C) 2003-2015 Mark Shelor, All Rights Reserved
  *
- * Version: 5.91
- * Fri May 16 10:21:44 MST 2014
+ * Version: 5.94
+ * Sat Jan 10 00:45:28 MST 2015
  *
  */
 
@@ -45,7 +45,7 @@
 #define K3	C32(0x8f1bbcdc)
 #define K4	C32(0xca62c1d6)
 
-static W32 K256[64] =			/* SHA-224/256 constants */
+static const W32 K256[64] =		/* SHA-224/256 constants */
 {
 	C32(0x428a2f98), C32(0x71374491), C32(0xb5c0fbcf), C32(0xe9b5dba5),
 	C32(0x3956c25b), C32(0x59f111f1), C32(0x923f82a4), C32(0xab1c5ed5),
@@ -65,19 +65,19 @@ static W32 K256[64] =			/* SHA-224/256 constants */
 	C32(0x90befffa), C32(0xa4506ceb), C32(0xbef9a3f7), C32(0xc67178f2)
 };
 
-static W32 H01[5] =			/* SHA-1 initial hash value */
+static const W32 H01[8] =		/* SHA-1 initial hash value */
 {
-	C32(0x67452301), C32(0xefcdab89), C32(0x98badcfe),
-	C32(0x10325476), C32(0xc3d2e1f0)
+	C32(0x67452301), C32(0xefcdab89), C32(0x98badcfe), C32(0x10325476),
+	C32(0xc3d2e1f0), C32(0x00000000), C32(0x00000000), C32(0x00000000)
 };
 
-static W32 H0224[8] =			/* SHA-224 initial hash value */
+static const W32 H0224[8] =		/* SHA-224 initial hash value */
 {
 	C32(0xc1059ed8), C32(0x367cd507), C32(0x3070dd17), C32(0xf70e5939),
 	C32(0xffc00b31), C32(0x68581511), C32(0x64f98fa7), C32(0xbefa4fa4)
 };
 
-static W32 H0256[8] =			/* SHA-256 initial hash value */
+static const W32 H0256[8] =		/* SHA-256 initial hash value */
 {
 	C32(0x6a09e667), C32(0xbb67ae85), C32(0x3c6ef372), C32(0xa54ff53a),
 	C32(0x510e527f), C32(0x9b05688c), C32(0x1f83d9ab), C32(0x5be0cd19)
@@ -88,7 +88,7 @@ static void sha1(SHA *s, UCHR *block)		/* SHA-1 transform */
 	W32 a, b, c, d, e;
 	W32 W[16];
 	W32 *wp = W;
-	W32 *H = (W32 *) s->H;
+	W32 *H = s->H32;
 
 	SHA32_SCHED(W, block);
 
@@ -154,9 +154,9 @@ static void sha256(SHA *s, UCHR *block)		/* SHA-224/256 transform */
 {
 	W32 a, b, c, d, e, f, g, h, T1;
 	W32 W[16];
-	W32 *kp = K256;
+	const W32 *kp = K256;
 	W32 *wp = W;
-	W32 *H = (W32 *) s->H;
+	W32 *H = s->H32;
 
 	SHA32_SCHED(W, block);
 
@@ -214,8 +214,9 @@ static void sha256(SHA *s, UCHR *block)		/* SHA-224/256 transform */
 
 #include "sha64bit.c"
 
-#define SETBIT(s, pos)	s[(pos) >> 3] |=  (0x01 << (7 - (pos) % 8))
-#define CLRBIT(s, pos)	s[(pos) >> 3] &= ~(0x01 << (7 - (pos) % 8))
+#define BITSET(s, pos)	s[(pos) >> 3] &  (UCHR)  (0x01 << (7 - (pos) % 8))
+#define SETBIT(s, pos)	s[(pos) >> 3] |= (UCHR)  (0x01 << (7 - (pos) % 8))
+#define CLRBIT(s, pos)	s[(pos) >> 3] &= (UCHR) ~(0x01 << (7 - (pos) % 8))
 #define NBYTES(nbits)	(((nbits) + 7) >> 3)
 #define HEXLEN(nbytes)	((nbytes) << 1)
 #define B64LEN(nbytes)	(((nbytes) % 3 == 0) ? ((nbytes) / 3) * 4 \
@@ -247,8 +248,8 @@ static UCHR *digcpy(SHA *s)
 {
 	int i;
 	UCHR *d = s->digest;
-	W32 *p32 = (W32 *) s->H;
-	W64 *p64 = (W64 *) s->H;
+	W32 *p32 = s->H32;
+	W64 *p64 = s->H64;
 
 	if (s->alg <= SHA256)
 		for (i = 0; i < 8; i++, d += 4)
@@ -265,8 +266,8 @@ static UCHR *digcpy(SHA *s)
 static UCHR *statecpy(SHA *s, UCHR *buf)
 {
 	int i;
-	W32 *p32 = (W32 *) s->H;
-	W64 *p64 = (W64 *) s->H;
+	W32 *p32 = s->H32;
+	W64 *p64 = s->H64;
 
 	if (s->alg <= SHA256)
 		for (i = 0; i < 8; i++, buf += 4)
@@ -282,7 +283,10 @@ static UCHR *statecpy(SHA *s, UCHR *buf)
 	do {								\
 		Zero(s, 1, SHA);					\
 		s->alg = algo; s->sha = sha ## transform;		\
-		Copy(H0 ## algo, s->H, sizeof(H0 ## algo), char);	\
+		if (s->alg <= SHA256)					\
+			Copy(H0 ## algo, s->H32, 8, SHA32);		\
+		else							\
+			Copy(H0 ## algo, s->H64, 8, SHA64);		\
 		s->blocksize = SHA ## algo ## _BLOCK_BITS;		\
 		s->digestlen = SHA ## algo ## _DIGEST_BITS >> 3;	\
 	} while (0)
@@ -356,43 +360,23 @@ static ULNG shabytes(UCHR *bitstr, ULNG bitcnt, SHA *s)
 /* shabits: updates state for bit-aligned data in s->block */
 static ULNG shabits(UCHR *bitstr, ULNG bitcnt, SHA *s)
 {
-	UINT i;
-	UINT gap;
-	ULNG nbits;
-	UCHR buf[1<<9];
-	UINT bufsize = sizeof(buf);
-	ULNG bufbits = (ULNG) bufsize << 3;
-	UINT nbytes = NBYTES(bitcnt);
-	ULNG savecnt = bitcnt;
+	ULNG i;
 
-	gap = 8 - s->blockcnt % 8;
-	s->block[s->blockcnt>>3] &= ~0 << gap;
-	s->block[s->blockcnt>>3] |= *bitstr >> (8 - gap);
-	s->blockcnt += bitcnt < gap ? bitcnt : gap;
-	if (bitcnt < gap)
-		return(savecnt);
-	if (s->blockcnt == s->blocksize)
-		s->sha(s, s->block), s->blockcnt = 0;
-	if ((bitcnt -= gap) == 0)
-		return(savecnt);
-	while (nbytes > bufsize) {
-		for (i = 0; i < bufsize; i++)
-			buf[i] = bitstr[i] << gap | bitstr[i+1] >> (8-gap);
-		nbits = bitcnt < bufbits ? bitcnt : bufbits;
-		shabytes(buf, nbits, s);
-		bitcnt -= nbits, bitstr += bufsize, nbytes -= bufsize;
+	for (i = 0UL; i < bitcnt; i++) {
+		if (BITSET(bitstr, i))
+			SETBIT(s->block, s->blockcnt), s->blockcnt++;
+		else
+			CLRBIT(s->block, s->blockcnt), s->blockcnt++;
+		if (s->blockcnt == s->blocksize)
+			s->sha(s, s->block), s->blockcnt = 0;
 	}
-	for (i = 0; i < nbytes - 1; i++)
-		buf[i] = bitstr[i] << gap | bitstr[i+1] >> (8-gap);
-	buf[nbytes-1] = bitstr[nbytes-1] << gap;
-	shabytes(buf, bitcnt, s);
-	return(savecnt);
+	return(bitcnt);
 }
 
 /* shawrite: triggers a state update using data in bitstr/bitcnt */
 static ULNG shawrite(UCHR *bitstr, ULNG bitcnt, SHA *s)
 {
-	if (bitcnt < 1)
+	if (!bitcnt)
 		return(0);
 	if (SHA_LO32(s->lenll += bitcnt) < bitcnt)
 		if (SHA_LO32(++s->lenlh) == 0)
@@ -434,13 +418,13 @@ static void shafinish(SHA *s)
 #define shadigest(state)	digcpy(state)
 
 /* xmap: translation map for hexadecimal encoding */
-static char xmap[] =
+static const char xmap[] =
 	"0123456789abcdef";
 
 /* shahex: returns pointer to current digest (hexadecimal) */
 static char *shahex(SHA *s)
 {
-	int i;
+	UINT i;
 	char *h;
 	UCHR *d;
 
@@ -457,11 +441,11 @@ static char *shahex(SHA *s)
 }
 
 /* bmap: translation map for Base 64 encoding */
-static char bmap[] =
+static const char bmap[] =
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
 /* encbase64: encodes input (0 to 3 bytes) into Base 64 */
-static void encbase64(UCHR *in, int n, char *out)
+static void encbase64(UCHR *in, UINT n, char *out)
 {
 	UCHR byte[3] = {0, 0, 0};
 
@@ -479,7 +463,7 @@ static void encbase64(UCHR *in, int n, char *out)
 /* shabase64: returns pointer to current digest (Base 64) */
 static char *shabase64(SHA *s)
 {
-	int n;
+	UINT n;
 	UCHR *q;
 	char out[5];
 
